@@ -388,7 +388,7 @@ class LocalPorvider(BaseProvider):
             fields: stockcode, weight
         """
         instruments = "000300.SH"
-        return TDP.get_daily_indexweight(instruments, **kws)
+        return TDP.get_daily_hs300weight(instruments, **kws)
 
     def get_daily_csi500weight(self, **kws):
         """
@@ -398,7 +398,7 @@ class LocalPorvider(BaseProvider):
             fields: stockcode, weight
         """
         instruments = "000905.SH"
-        return TDP.get_daily_indexweight(instruments, **kws)
+        return TDP.get_daily_csi500weight(instruments, **kws)
 
     def index_member(self, indexcode: str, start_date: str = None, end_date: str = None):
         """
